@@ -1,26 +1,31 @@
-#' 2d contours of a 3d surface
+#' 2D contours of a 3D surface
 #'
-#' ggplot2 can not draw true 3d surfaces, but you can use `geom_contour`
-#' and [geom_tile()] to visualise 3d surfaces in 2d. To be a valid
-#' surface, the data must contain only a single row for each unique combination
-#' of the variables mapped to the `x` and `y` aesthetics. Contouring
-#' tends to work best when `x` and `y` form a (roughly) evenly
-#' spaced grid. If your data is not evenly spaced, you may want to interpolate
-#' to a grid before visualising.
+#' ggplot2 can not draw true 3D surfaces, but you can use `geom_contour()`,
+#' `geom_contour_filled()`, and [geom_tile()] to visualise 3D surfaces in 2D. To
+#' specify a valid surface, the data must contain `x`, `y`, and `z` coordinates,
+#' and each unique combination of `x` and `y` can appear at most once.
+#' Contouring requires that the points can be rearranged so that the `z` values
+#' form a matrix, with rows corresponding to unique `x` values, and columns
+#' corresponding to unique `y` values. Missing entries are allowed, but contouring
+#' will only be done on cells of the grid with all four `z` values present. If
+#' your data is irregular, you can interpolate to a grid before visualising
+#' using the [interp::interp()] function from the `interp` package
+#' (or one of the interpolating functions from the `akima` package.)
 #'
 #' @eval rd_aesthetics("geom", "contour")
+#' @eval rd_aesthetics("geom", "contour_filled")
 #' @inheritParams layer
 #' @inheritParams geom_point
 #' @inheritParams geom_path
 #' @param bins Number of contour bins. Overridden by `binwidth`.
 #' @param binwidth The width of the contour bins. Overridden by `breaks`.
-#' @param breaks Numeric vector to set the contour breaks.
-#'   Overrides `binwidth` and `bins`. By default, this is a vector of
-#'   length ten with [pretty()] breaks.
+#' @param breaks Numeric vector to set the contour breaks. Overrides `binwidth`
+#'   and `bins`. By default, this is a vector of length ten with [pretty()]
+#'   breaks.
 #' @seealso [geom_density_2d()]: 2d density contours
 #' @export
 #' @examples
-#' #' # Basic plot
+#' # Basic plot
 #' v <- ggplot(faithfuld, aes(waiting, eruptions, z = density))
 #' v + geom_contour()
 #'
@@ -33,8 +38,8 @@
 #' v + geom_contour_filled()
 #'
 #' # Setting bins creates evenly spaced contours in the range of the data
-#' v + geom_contour(bins = 2)
-#' v + geom_contour(bins = 10)
+#' v + geom_contour(bins = 3)
+#' v + geom_contour(bins = 5)
 #'
 #' # Setting binwidth does the same thing, parameterised by the distance
 #' # between contours
@@ -46,6 +51,22 @@
 #' v + geom_contour(colour = "red")
 #' v + geom_raster(aes(fill = density)) +
 #'   geom_contour(colour = "white")
+#'
+#' # Irregular data
+#' if (requireNamespace("interp")) {
+#'   # Use a dataset from the interp package
+#'   data(franke, package = "interp")
+#'   origdata <- as.data.frame(interp::franke.data(1, 1, franke))
+#'   grid <- with(origdata, interp::interp(x, y, z))
+#'   griddf <- subset(data.frame(x = rep(grid$x, nrow(grid$z)),
+#'                               y = rep(grid$y, each = ncol(grid$z)),
+#'                               z = as.numeric(grid$z)),
+#'                    !is.na(z))
+#'   ggplot(griddf, aes(x, y, z = z)) +
+#'     geom_contour_filled() +
+#'     geom_point(data = origdata)
+#' } else
+#'   message("Irregular data requires the 'interp' package")
 #' }
 geom_contour <- function(mapping = NULL, data = NULL,
                          stat = "contour", position = "identity",
@@ -95,7 +116,7 @@ geom_contour_filled <- function(mapping = NULL, data = NULL,
     data = data,
     mapping = mapping,
     stat = stat,
-    geom = GeomPolygon,
+    geom = GeomContourFilled,
     position = position,
     show.legend = show.legend,
     inherit.aes = inherit.aes,
@@ -123,3 +144,11 @@ GeomContour <- ggproto("GeomContour", GeomPath,
     alpha = NA
   )
 )
+
+#' @rdname ggplot2-ggproto
+#' @format NULL
+#' @usage NULL
+#' @export
+#' @include geom-polygon.r
+GeomContourFilled <- ggproto("GeomContourFilled", GeomPolygon)
+
